register_allocator_mimalloc

Function register_allocator_mimalloc 

pub fn register_allocator_mimalloc()
Records that the final artifact uses mimalloc as its Rust global allocator.

This only affects version header metadata. The final artifact must declare mimalloc as its global allocator before calling this function.