pub fn register_allocator_mimalloc()Expand description
Records that the final artifact uses mimalloc as its Rust global allocator.
This only affects version header metadata. The final artifact must declare mimalloc as its global allocator before calling this function.